@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 import unittest
 import aipy.amp as amp, numpy as n
 
@@ -8,6 +9,7 @@ class TestRadioBody(unittest.TestCase):
         ant0 = amp.Antenna(0,0,0,bm)
         self.aa = amp.AntennaArray(('0','0'), [ant0])
     def test_attributes(self):
+        """Test aipy.amp.RadioFixedBody attributes"""
         s = amp.RadioFixedBody('0:00', '0:00',
             jys=100, index=-2, mfreq=.1, name='src1')
         self.assertEqual(s._jys, 100)
@@ -20,6 +22,7 @@ class TestBeam(unittest.TestCase):
         self.fqs = n.arange(.1,.2,.01)
         self.bm = amp.Beam(self.fqs)
     def test_response(self):
+        """Test retrieving aipy.amp.Beam response"""
         xyz = (0,0,1)
         self.assertTrue(n.all(self.bm.response(xyz) == n.ones_like(self.fqs)))
         x = n.array([0, .1, .2])
@@ -36,6 +39,7 @@ class TestBeam2DGaussian(unittest.TestCase):
         self.fqs = n.arange(.1,.2,.01)
         self.bm = amp.Beam2DGaussian(self.fqs, .05, .025)
     def test_response(self):
+        """Test retrieving a 2D Gaussian beam response"""
         xyz = (0,0,1)
         self.assertTrue(n.all(self.bm.response(xyz) == n.ones_like(self.fqs)))
         x = n.array([0, .05,   0])
@@ -58,12 +62,14 @@ class TestAntenna(unittest.TestCase):
         bm = amp.Beam2DGaussian(self.fqs, .05, .025)
         self.ant = amp.Antenna(0,0,0, beam=bm)
     def test_passband(self):
+        """Test the Antenna passband"""
         pb = self.ant.passband()
         self.assertTrue(n.all(pb == n.ones_like(self.fqs)))
         self.ant.select_chans([0,1,2])
         pb = self.ant.passband()
         self.assertEqual(pb.shape, (3,))
     def test_bm_response(self):
+        """Test the Antenna beam response"""
         xyz = (.05,0,1)
         self.ant.select_chans([0])
         resp = self.ant.bm_response(xyz, pol='x')
@@ -82,5 +88,18 @@ class TestAntenna(unittest.TestCase):
 #        ants = [amp.Antenna(0,0,0,beam) for i in range(100)]
 #        while True: aa = amp.AntennaArray(('0:00','0:00'), ants)
         
+class TestSuite(unittest.TestSuite):
+    """A unittest.TestSuite class which contains all of the aipy.amp unit tests."""
+
+    def __init__(self):
+        unittest.TestSuite.__init__(self)
+
+        loader = unittest.TestLoader()
+        self.addTests(loader.loadTestsFromTestCase(TestRadioBody))
+        self.addTests(loader.loadTestsFromTestCase(TestBeam))
+        self.addTests(loader.loadTestsFromTestCase(TestBeam2DGaussian))
+        self.addTests(loader.loadTestsFromTestCase(TestAntenna))
+        #self.addTests(loader.loadTestsFromTestCase(TestMemLeaks))
+
 if __name__ == '__main__':
     unittest.main()
