@@ -1,9 +1,11 @@
+# -*- coding: utf-8 -*-
 import unittest, aipy as a, numpy as n, re
 from aipy.miriad import ij2bl
 
 class TestParseAnts(unittest.TestCase):
     'Tests aipy.scripting.parse_ants()'
     def testant4(self):
+        """Test aipy.scripting.parse_ants()"""
         nants = 4
         cases = {
             'all': [],
@@ -27,8 +29,9 @@ class TestParseAnts(unittest.TestCase):
         self.assertRaises(ValueError, a.scripting.parse_ants, '(0_1)_2', nants)
 
 class TestParseSrcs(unittest.TestCase):
-    'Tests aipy.scriptin.parse_srcs()'
+    'Tests aipy.scripting.parse_srcs()'
     def testsrc(self):
+        """Test aipy.scripting.parse_srcs()"""
         cat = 'misc,helm'
         src_opt = 'cyg,cas,12_40,12:00_40:00,12:00:00.0_40:00:00.0,bug_man'
         srclist,cutoff,catalogs = a.scripting.parse_srcs(src_opt, cat)
@@ -51,12 +54,14 @@ class TestParseChans(unittest.TestCase):
             '5,7,40_50': [n.array([5]),n.array([7]),n.arange(40,51)],
         }
     def testchan_concat(self):
+        """Test aipy.scripting.parse_chans() - concatenate"""
         for case in self.cases:
             chans = a.scripting.parse_chans(case, self.nchan, concat=True)
             self.assertTrue(n.all(chans == n.concatenate(self.cases[case])))
         self.assertRaises(AssertionError,
             a.scripting.parse_chans, '0_1_2_3', self.nchan)
     def testchan_noconcat(self):
+        """Test aipy.scripting.parse_chans() - without concatenate"""
         for case in self.cases:
             chans = a.scripting.parse_chans(case, self.nchan, concat=False)
             for ch1, ch2 in zip(chans, self.cases[case]):
@@ -76,6 +81,7 @@ class TestParsePrms(unittest.TestCase):
             '(src13/src14/src15)=(jys/index)//1',
         ]
     def testname(self):
+        """Test aipy.scripting.name matching"""
         r = re.compile(a.scripting.name)
         self.assertEqual(r.match('src1').groups(), ('src1',))
         self.assertEqual(r.match('1').groups(), ('1',))
@@ -86,6 +92,7 @@ class TestParsePrms(unittest.TestCase):
         self.assertEqual(r.match('1)1').groups(), ('1',))
         self.assertEqual(r.match(')1'), None)
     def testgrp(self):
+        """Test aipy.scripting.grp matching"""
         r = re.compile(a.scripting.grp)
         self.assertEqual(r.match('src1').groups()[0], 'src1')
         self.assertEqual(r.match('src1/src2').groups()[0], 'src1')
@@ -94,10 +101,12 @@ class TestParsePrms(unittest.TestCase):
         self.assertEqual(r.match('(src1/)'), None)
         self.assertEqual(r.match('(src1/src2'), None)
     def testprm(self):
+        """Test aipy.scripting.prm_rgx matching"""
         r = a.scripting.prm_rgx
         for t in self.test_strs:
             self.assertEqual(r.match(t).groups()[0], t)
     def testprmlist(self):
+        """Test aipy.scripting.parse_prms()"""
         t = ','.join(self.test_strs)
         prms = a.scripting.parse_prms(t)
         self.assertEqual(prms['src1']['jys'], (None,None))
@@ -128,6 +137,18 @@ class TestParsePrms(unittest.TestCase):
         prms = a.scripting.parse_prms('a=(b/c)')
         self.assertEqual(len(prms['a']), 2)
 
+class TestSuite(unittest.TestSuite):
+    """A unittest.TestSuite class which contains all of the aipy.coord unit tests."""
+
+    def __init__(self):
+        unittest.TestSuite.__init__(self)
+
+        loader = unittest.TestLoader()
+        self.addTests(loader.loadTestsFromTestCase(TestParseAnts))
+        self.addTests(loader.loadTestsFromTestCase(TestParseSrcs))
+        self.addTests(loader.loadTestsFromTestCase(TestParseChans))
+        self.addTests(loader.loadTestsFromTestCase(TestParsePrms))
+
 if __name__ == '__main__':
     unittest.main()
 
